@@ -19,7 +19,9 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
 #include <glib/gstrfuncs.h>
+#include <bonobo/bonobo-i18n.h>
 #include <gtk/gtkframe.h>
 #include <gtk/gtkscrolledwindow.h>
 #include <gtk/gtkvpaned.h>
@@ -77,19 +79,17 @@ components_sql_view_init (ComponentsSqlView *sql_view, ComponentsSqlViewClass *k
 	sql_view->priv = g_new0 (ComponentsSqlViewPrivate, 1);
 	sql_view->priv->cnc = NULL;
 
-	frame = gnome_db_new_frame_widget (NULL);
-	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_OUT);
-	gtk_widget_show(frame);
-	gtk_box_pack_start (GTK_BOX (sql_view), frame, 1, 1, 0);
-
 	sql_view->priv->paned = gnome_db_new_vpaned_widget ();
 	gtk_widget_show (sql_view->priv->paned);
-	gtk_container_add (GTK_CONTAINER (frame), sql_view->priv->paned);
+	gtk_box_pack_start (GTK_BOX (sql_view), sql_view->priv->paned, 1, 1, 0);
 
 	/* create the SQL buffer */
+	frame = gnome_db_new_frame_widget (NULL);
+	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
 	sql_view->priv->text = gnome_db_sql_editor_new ();
 	gtk_widget_show (sql_view->priv->text);
-	gtk_paned_add1 (GTK_PANED (sql_view->priv->paned), sql_view->priv->text);
+	gtk_container_add (GTK_CONTAINER (frame), sql_view->priv->text);
+	gtk_paned_add1 (GTK_PANED (sql_view->priv->paned), frame);
 
 	/* create the grid widget */
 	sql_view->priv->grid = gnome_db_grid_new ();
@@ -226,22 +226,42 @@ components_sql_view_set_connection (ComponentsSqlView *sql_view, GdaConnection *
 
 	sql_view->priv->cnc = cnc;
 
-	/* gnome_db_text_clear (gnome_db_sql_editor_get_text_view(
-		GNOME_DB_SQL_EDITOR(sql_view->priv->text))); */
+	gnome_db_text_clear (gnome_db_sql_editor_get_text_view (
+				     GNOME_DB_SQL_EDITOR (sql_view->priv->text)));
 	gnome_db_grid_set_model (GNOME_DB_GRID (sql_view->priv->grid), NULL);
 }
 
 void
 components_sql_view_open_command (ComponentsSqlView *sql_view)
 {
-	gchar *cmd;
+	gchar *uri;
 
-	cmd = command_dialog_open ();
-	if (cmd) {
-		gnome_db_text_set_text (gnome_db_sql_editor_get_text_view(
-			GNOME_DB_SQL_EDITOR(sql_view->priv->text)),
-					cmd, strlen (cmd));
-		g_free (cmd);
+	uri = gnome_db_select_file_dialog (gtk_widget_get_toplevel (GTK_WIDGET (sql_view)),
+					   _("Select SQL file"));
+	if (uri) {
+		if (!gnome_db_sql_editor_load_from_file (
+			    GNOME_DB_SQL_EDITOR (sql_view->priv->text), uri)) {
+			gnome_db_show_error (_("Could not load file at %s"), uri);
+		}
+
+		g_free (uri);
+	}
+}
+
+void
+components_sql_view_save_command (ComponentsSqlView *sql_view)
+{
+	gchar *uri;
+
+	uri = gnome_db_select_file_dialog (gtk_widget_get_toplevel (GTK_WIDGET (sql_view)),
+					   _("Select SQL file"));
+	if (uri) {
+		if (!gnome_db_sql_editor_save_to_file (
+			    GNOME_DB_SQL_EDITOR (sql_view->priv->text), uri)) {
+			gnome_db_show_error (_("Could not save to %s"), uri);
+		}
+
+		g_free (uri);
 	}
 }
 
