@@ -19,13 +19,18 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
+#include <string.h>
 #include <bonobo/bonobo-i18n.h>
 #include <libgda/gda-config.h>
 #include <gtk/gtkdialog.h>
+#include <gtk/gtklabel.h>
 #include <gtk/gtknotebook.h>
 #include <gtk/gtkstock.h>
 #include <libgnomedb/gnome-db-dsn-config.h>
 #include <libgnomedb/gnome-db-grid.h>
+#include <libgnomedb/gnome-db-util.h>
+#include <libgnomeui/gnome-window-icon.h>
 #include "components-manager-view.h"
 
 #define PARENT_TYPE GTK_TYPE_VBOX
@@ -134,7 +139,7 @@ components_manager_view_init (ComponentsManagerView *view, ComponentsManagerView
 	gtk_box_pack_start (GTK_BOX (view), view->priv->notebook, TRUE, TRUE, 0);
 
 	/* dsn tab */
-	view->priv->dsn_tab = gnome_db_new_hbox_widget ();
+	view->priv->dsn_tab = gnome_db_new_hbox_widget (FALSE, 0);
 	gtk_notebook_append_page (GTK_NOTEBOOK (view->priv->notebook),
 				  view->priv->dsn_tab, gtk_label_new (_("Data Sources")));
 
@@ -148,7 +153,7 @@ components_manager_view_init (ComponentsManagerView *view, ComponentsManagerView
 	gtk_box_pack_start (GTK_BOX (view->priv->dsn_tab), view->priv->dsn_list, TRUE, TRUE, 0);
 
 	/* providers tab */
-	view->priv->providers_tab = gnome_db_new_hbox_widget ();
+	view->priv->providers_tab = gnome_db_new_hbox_widget (FALSE, 0);
 	gtk_notebook_append_page (GTK_NOTEBOOK (view->priv->notebook),
 				  view->priv->providers_tab,
 				  gtk_label_new (_("Providers")));
@@ -229,7 +234,7 @@ components_manager_view_delete_selected (ComponentsManagerView *view)
 
 		for (l = selection; l != NULL; l = l->next) {
 			str = gda_value_stringify (
-				gda_data_model_get_value_at (model, 0,
+				(GdaValue *) gda_data_model_get_value_at (model, 0,
 							     GPOINTER_TO_INT (l->data)));
 			if (gnome_db_yes_no_dialog (
 				    gtk_widget_get_toplevel (GTK_WIDGET (view)),
@@ -267,7 +272,8 @@ components_manager_view_show_properties (ComponentsManagerView *view)
 
 	model = gnome_db_grid_get_model (GNOME_DB_GRID (view->priv->dsn_list));
 	str = gda_value_stringify (
-		gda_data_model_get_value_at (model, 0, GPOINTER_TO_INT (selection->data)));
+		(GdaValue *) gda_data_model_get_value_at (model, 0,
+					GPOINTER_TO_INT (selection->data)));
 
 	dsn_info = gda_config_find_data_source (str);
 	g_free (str);
@@ -277,7 +283,7 @@ components_manager_view_show_properties (ComponentsManagerView *view)
 	/* show the properties */
 	dialog = gtk_dialog_new_with_buttons (
 		_("Properties"),
-		GTK_WINDOW (gtk_widget_get_toplevel (view)), 0,
+		GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (view))), 0,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 		GTK_STOCK_SAVE, GTK_RESPONSE_OK,
 		NULL);
