@@ -19,8 +19,11 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
 #include <bonobo/bonobo-i18n.h>
 #include <libgnomedb/gnome-db-dsn-config-druid.h>
+#include <libgnomedb/gnome-db-util.h>
+#include <libgnomeui/gnome-window-icon.h>
 #include "components-manager.h"
 #include "components-manager-view.h"
 
@@ -59,7 +62,9 @@ verb_EditDelete (BonoboUIComponent *uic, void *user_data, const char *path)
 
 	g_return_if_fail (COMPONENTS_IS_MANAGER (comp));
 
-	control = gnome_db_shell_component_get_control (comp);
+	control = gnome_db_shell_component_get_control (
+			GNOME_DB_SHELL_COMPONENT (comp));
+
 	g_return_if_fail (GNOME_DB_IS_CONTROL (control));
 
 	components_manager_view_delete_selected (
@@ -75,7 +80,9 @@ verb_EditProperties (BonoboUIComponent *uic, void *user_data, const char *path)
 
 	g_return_if_fail (COMPONENTS_IS_MANAGER (comp));
 
-	control = gnome_db_shell_component_get_control (comp);
+	control = gnome_db_shell_component_get_control (
+			GNOME_DB_SHELL_COMPONENT (comp));
+
 	g_return_if_fail (GNOME_DB_IS_CONTROL (control));
 
 	components_manager_view_show_properties (
@@ -91,7 +98,9 @@ verb_EditSelectAll (BonoboUIComponent *uic, void *user_data, const char *path)
 
 	g_return_if_fail (COMPONENTS_IS_MANAGER (comp));
 
-	control = gnome_db_shell_component_get_control (comp);
+	control = gnome_db_shell_component_get_control (
+			GNOME_DB_SHELL_COMPONENT (comp));
+
 	g_return_if_fail (GNOME_DB_IS_CONTROL (control));
 
 	components_manager_view_select_all (
@@ -107,7 +116,9 @@ verb_EditUnselectAll (BonoboUIComponent *uic, void *user_data, const char *path)
 
 	g_return_if_fail (COMPONENTS_IS_MANAGER (comp));
 
-	control = gnome_db_shell_component_get_control (comp);
+	control = gnome_db_shell_component_get_control (
+			GNOME_DB_SHELL_COMPONENT (comp));
+
 	g_return_if_fail (GNOME_DB_IS_CONTROL (control));
 
 	components_manager_view_unselect_all (
@@ -150,13 +161,16 @@ verb_ManagerNewDsn (BonoboUIComponent *uic, void *user_data, const char *path)
 
 	g_return_if_fail (COMPONENTS_IS_MANAGER (comp));
 
-	control = gnome_db_shell_component_get_control (comp);
+	control = gnome_db_shell_component_get_control (
+			GNOME_DB_SHELL_COMPONENT (comp));
+
 	g_return_if_fail (GNOME_DB_IS_CONTROL (control));
 
 	/* create the window to contain the druid */
 	dialog = gtk_dialog_new_with_buttons (
 		_("New data source"),
-		GTK_WINDOW (gtk_widget_get_toplevel (bonobo_control_get_widget (control))),
+		GTK_WINDOW (gtk_widget_get_toplevel (
+			bonobo_control_get_widget (BONOBO_CONTROL (control)))),
 		0, NULL);
 	gnome_window_icon_set_from_file (GTK_WINDOW (dialog),
 					 GNOME_DB_PIXMAPDIR "/gnome-db.png");
