@@ -26,8 +26,9 @@
 /*
  * Bonobo components IDs
  */
-#define GNOME_DB_ID_DATABASE "OAFIID:GNOME_Database_UIDatabaseComponent"
-#define GNOME_DB_ID_MANAGER  "OAFIID:GNOME_Database_UIManagerComponent"
+#define GNOME_DB_ID_DATABASE        "OAFIID:GNOME_Database_UIDatabaseComponent"
+#define GNOME_DB_ID_DATABASE_CONFIG "OAFIID:GNOME_Database_UIDatabaseConfigComponent"
+#define GNOME_DB_ID_MANAGER         "OAFIID:GNOME_Database_UIManagerComponent"
 
 /*
  * Definitions for configuration entries
@@ -35,13 +36,14 @@
 #define GNOME_DB_SHELL_CONFIG_SECTION_SHELL "/apps/gnome-db/Shell"
 #define GNOME_DB_SHELL_CONFIG_SECTION_LOAD  "/apps/gnome-db/Shell/Load"
 
-#define GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT   "/apps/gnome-db/Shell/ShowShortcut"
-#define GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY    "/apps/gnome-db/Shell/ShowSummary"
-#define GNOME_DB_SHELL_CONFIG_SAVE_WINDOW_POS "/apps/gnome-db/Shell/SaveWindowPos"
-#define GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_X1  "/apps/gnome-db/Shell/MainWindowX1"
-#define GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_X2  "/apps/gnome-db/Shell/MainWindowX2"
-#define GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_Y1  "/apps/gnome-db/Shell/MainWindowY1"
-#define GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_Y2  "/apps/gnome-db/Shell/MainWindowY2"
+#define GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT    "/apps/gnome-db/Shell/ShowShortcut"
+#define GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY     "/apps/gnome-db/Shell/ShowSummary"
+#define GNOME_DB_SHELL_CONFIG_SAVE_WINDOW_POS  "/apps/gnome-db/Shell/SaveWindowPos"
+#define GNOME_DB_SHELL_CONFIG_FIXED_WINDOW_POS "/apps/gnome-db/Shell/FixedWindowPos"
+#define GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_X1   "/apps/gnome-db/Shell/MainWindowX1"
+#define GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_X2   "/apps/gnome-db/Shell/MainWindowX2"
+#define GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_Y1   "/apps/gnome-db/Shell/MainWindowY1"
+#define GNOME_DB_SHELL_CONFIG_MAIN_WINDOW_Y2   "/apps/gnome-db/Shell/MainWindowY2"
 
 #define GNOME_DB_SHELL_CONFIG_DEFAULT_COMPONENT "/apps/gnome-db/Shell/DefaultComponent"
 
