@@ -113,34 +113,29 @@ add_components_to_shortcut (GnomeDbShell *shell)
 	if (components) {
 		GList *node;
 		GnomeDbComponentInfo *comp_info;
-		gchar *str;
           
 		for (node = g_list_first (components);
 		     node != NULL;
 		     node = g_list_next (node)) {
+			GdaParameter *param;
+			gchar *shell_icon;
+
 			comp_info = (GnomeDbComponentInfo *) node->data;
-			str = g_strdup_printf ("%s/%s",
-					       GNOME_DB_SHELL_CONFIG_SECTION_LOAD,
-					       comp_info->id);
-			if (gda_config_has_key (str)) {
-				GdaParameter *param;
-				gchar *shell_icon;
 
-				param = gda_parameter_list_find (comp_info->properties,
-								 "shell-icon");
-				shell_icon = gda_value_stringify (gda_parameter_get_value (param));
-				gnome_db_shortcut_append (
-					GNOME_DB_SHORTCUT (shell->priv->shortcut),
-					comp_info->description,
-					comp_info->id,
-					shell_icon,
-					shortcut_button_clicked_cb,
-					(gpointer) shell);
+			param = gda_parameter_list_find (comp_info->properties,
+							 "shell-icon");
+			shell_icon = gda_value_stringify (gda_parameter_get_value (param));
+			gnome_db_shortcut_append (
+				GNOME_DB_SHORTCUT (shell->priv->shortcut),
+				comp_info->description,
+				comp_info->id,
+				shell_icon,
+				shortcut_button_clicked_cb,
+				(gpointer) shell);
 
-				g_free (shell_icon);
-			}
-			g_free (str);
+			g_free (shell_icon);
 		}
+
 		gnome_db_config_free_component_list (components);
 	}
 
@@ -166,7 +161,7 @@ setup_window (GnomeDbShell *shell)
 
 	/* create the window for this shell */
 	shell->priv->window = gnome_db_window_new ("gnome-db",
-						   GNOME_DB_DATADIR,
+						   GNOMEDB_DATADIR,
 						   "gnome-db.xml",
 						   shell_verbs,
 						   shell);
@@ -176,7 +171,7 @@ setup_window (GnomeDbShell *shell)
 	g_free (title);
 	gnome_window_icon_set_from_file (
 		GTK_WINDOW (shell->priv->window),
-		GNOME_DB_PIXMAPDIR "/gnome-db.png");
+		GNOMEDB_PIXMAPDIR "/gnome-db.png");
 
 	shell->priv->workarea = gtk_hpaned_new ();
 	shell->priv->shortcut = gnome_db_shortcut_new ();
@@ -382,7 +377,7 @@ verb_HelpAbout (BonoboUIComponent *uic, void *user_data, const char *path)
 
 	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
 
-	logo = gdk_pixbuf_new_from_file (GNOME_DB_PIXMAPDIR "/gnome-db.png", NULL);
+	logo = gdk_pixbuf_new_from_file (GNOMEDB_PIXMAPDIR "/gnome-db.png", NULL);
 
         dialog = gnome_about_new (_("GNOME-DB"), VERSION,
                                   _("Copyright 2001, The GNOME Foundation"),
@@ -422,7 +417,7 @@ verb_ToolsSettings (BonoboUIComponent *uic, void *user_data, const char *path)
 		GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL,
 		NULL);
 	gnome_window_icon_set_from_file (GTK_WINDOW (dialog),
-					 GNOME_DB_PIXMAPDIR "/gnome-db.png");
+					 GNOMEDB_PIXMAPDIR "/gnome-db.png");
 
 	settings = gnome_db_shell_settings_new (shell);
 	gtk_widget_show (settings);
